@@ -10,9 +10,9 @@ package Devel::Cover::Report::Html_basic;
 use strict;
 use warnings;
 
-our $VERSION = "0.58";
+our $VERSION = "0.59";
 
-use Devel::Cover::DB 0.58;
+use Devel::Cover::DB 0.59;
 
 use Getopt::Long;
 use Template 2.00;
@@ -104,13 +104,13 @@ sub _highlight_ppi {
     my $pretty =  $highlight->html($document);
 
     my $split = '<span class="line_number">';
-    
+
     # turn significant whitespace into &nbsp;
     @all_lines = map {
         $_ =~ s{</span>( +)}{"</span>" . ("&nbsp;" x length($1))}e;
         "$split$_";
     } split /$split/, $pretty;
-    
+
     # remove the line number
     @all_lines = map {
         s{<span class="line_number">.*?</span>}{}; $_;
@@ -118,7 +118,7 @@ sub _highlight_ppi {
     @all_lines = map {
         s{<span class="line_number">}{}; $_;
     } @all_lines;
-    
+
     # remove the BR
     @all_lines = map {
         s{<br>$}{}; $_;
@@ -126,7 +126,7 @@ sub _highlight_ppi {
     @all_lines = map {
         s{<br>\n</span>}{</span>}; $_;
     } @all_lines;
-    
+
     shift @all_lines if $all_lines[0] eq "";
     return @all_lines;
 }
@@ -164,7 +164,7 @@ sub print_file
     my @all_lines = <F>;
 
     @all_lines = _highlight(@all_lines) if $HAVE_HIGHLIGHTER;
-    
+
     my $linen = 1;
     LINE: while (defined(my $l = shift @all_lines))
     {
@@ -447,7 +447,7 @@ package Devel::Cover::Report::Html_basic::Template::Provider;
 use strict;
 use warnings;
 
-our $VERSION = "0.58";
+our $VERSION = "0.59";
 
 use base "Template::Provider";
 
@@ -462,20 +462,19 @@ sub fetch
 }
 
 $Templates{html} = <<'EOT';
-<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE html
+     PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"
+     "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
+<html xmlns="http://www.w3.org/1999/xhtml">
 <!--
-This file was generated by Devel::Cover Version 0.58
+This file was generated by Devel::Cover Version 0.59
 Devel::Cover is copyright 2001-2006, Paul Johnson (pjcj\@cpan.org)
 Devel::Cover is free. It is licensed under the same terms as Perl itself.
 The latest version of Devel::Cover should be available from my homepage:
 http://www.pjcj.net
 -->
-<!DOCTYPE html
-     PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"
-     "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
-<html xmlns="http://www.w3.org/1999/xhtml">
 <head>
-    <meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1"></meta>
+    <meta http-equiv="Content-Type" content="text/html; charset=utf-8"></meta>
     <meta http-equiv="Content-Language" content="en-us"></meta>
     <link rel="stylesheet" type="text/css" href="cover.css"></link>
     <title> [% title %] </title>
@@ -753,7 +752,7 @@ Huh?
 
 =head1 VERSION
 
-Version 0.58 - 6th August 2006
+Version 0.59 - 23rd August 2006
 
 =head1 LICENCE
 
@@ -842,7 +841,6 @@ pre,.s {
  *   c2  : coverage >= 90%
  *   c3  : path covered or coverage = 100%
  */
- c0, .c1, .c2, .c3 { text-align: right; }
 .c0 {
     background-color: #ff9999;
     border: solid 1px #cc0000;
