@@ -4,10 +4,10 @@ use strict;
 use warnings;
 use CGI;
 use Getopt::Long;
-use Devel::Cover::DB 0.58;
-use Devel::Cover::Truth_Table 0.58;
+use Devel::Cover::DB 0.59;
+use Devel::Cover::Truth_Table 0.59;
 
-our $VERSION = "0.58";
+our $VERSION = "0.59";
 
 #-------------------------------------------------------------------------------
 # Subroutine : get_coverage_for_line
@@ -256,22 +256,23 @@ sub print_html_header {
     my $title = shift;
 
     print $fh <<"END_HTML";
-<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE html
+     PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"
+     "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
+<html xmlns="http://www.w3.org/1999/xhtml">
 <!--
-This file was generated by Devel::Cover Version 0.58
+This file was generated by Devel::Cover Version 0.59
 Devel::Cover is copyright 2001-2006, Paul Johnson (pjcj\@cpan.org)
 Devel::Cover is free. It is licensed under the same terms as Perl itself.
 The latest version of Devel::Cover should be available from my homepage:
 http://www.pjcj.net
 -->
-<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML Basic 1.0//EN"
-    "http://www.w3.org/TR/xhtml-basic/xhtml-basic10.dtd">
-<html xmlns="http://www.w3.org/1999/xhtml">
 <head>
-<meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1"></meta>
-<meta http-equiv="Content-Language" content="en-us"></meta>
-<link rel="stylesheet" type="text/css" href="cover.css"></link>
-<title>$title</title>
+    <meta http-equiv="Content-Type" content="text/html; charset=utf-8"></meta>
+    <meta http-equiv="Content-Language" content="en-us"></meta>
+    <link rel="stylesheet" type="text/css" href="cover.css"></link>
+    <link rel="stylesheet" type="text/css" href="cover.css"></link>
+    <title>$title</title>
 </head>
 END_HTML
 
@@ -774,7 +775,7 @@ Devel::Cover
 
 =head1 VERSION
 
-Version 0.58 - 6th August 2006
+Version 0.59 - 23rd August 2006
 
 =head1 LICENCE
 
